@@ -11,8 +11,7 @@ import os
 
 secret_key = os.environ.get("ARCHETYPE_SECRET_KEY")
 app_id = os.environ.get("ARCHETYPE_APP_ID")
-prod_api_base = os.environ.get("ARCHETYPE_API_PROD_URL", "https://staging-production-xbh6rhecwq-uc.a.run.app")
-test_api_base = os.environ.get("ARCHETYPE_API_TEST_URL", "https://test.archetype.dev")
+prod_api_base = os.environ.get("ARCHETYPE_API_PROD_URL", "https://api.archetype.dev")
 upload_api_base = "https://files.archetype.dev"
 auth_version = 4
 record_auth_requests = True
