@@ -1,6 +1,6 @@
 from __future__ import absolute_import, division, print_function
 
-from archetypewsgi.api_resources.api_resource import (
+from archetypesdk.api_resources.api_resource import (
     CreatableAPIResource,
     RetrievableAPIResource,
     ListableAPIResource,
