@@ -1,4 +1,4 @@
-from archetypewsgi.enums import Method
+from archetypesdk.enums import Method
 
 
 class APIRequestError(Exception):
